timeintervaltools.compute_depth_of_intervals_in_interval
========================================================

.. autofunction:: abjad.tools.timeintervaltools.compute_depth_of_intervals_in_interval.compute_depth_of_intervals_in_interval
